import pandas as pd
import networkx as nx

def read_txt_networks(file_name):
    data = open(file_name).readlines()
    set = []
    for line in data:
        a,b = line.split('\t')
        a = int(a)
        b = int(b.strip('\n'))
        #print(a,b)
        set.append((a,b))
    print(set[1])
    print("max index: "+str(max(set[len(set)-1])))
    print("Warning: This is only a reference value for the number of nodes, and if there is no largest isolated node, the value plus 1 is the total number of nodes")
    return set

def build_txt_network(set,max_node):
    G = nx.Graph()
    Node = nx.path_graph(max_node)
    G.add_nodes_from(Node)
    G.add_edges_from(set)
    return G


import networkx as nx
import random
import tqdm


def empty_network(nodes_number):
    G = nx.Graph()
    Node = nx.path_graph(nodes_number)
    G.add_nodes_from(Node)
    return G


def rand_edge(G, vi, vj, p=0.8):  # 默认概率p=0.1
    probability = random.random()  # 生成随机小数
    if probability > p:  # 如果大于p
        # print(probability)
        G.add_edge(vi, vj)
    return G

###def create_random_networks(G,nodes_number,p=0.8):
#   i = 0
#    while i<nodes_number:
 #       j = 0
  #      while j<nodes_number:
   #         if j<i:
    #            j+=1
     #       else:
      #          rand_edge(G=G,vi=i,vj=j,p=p)
       #         j+=1
        #i+=1
    #return G
def create_random_networks(G,nodes_number,p=0.8):
    #i = 0
    for i in tqdm.tqdm(range(0,nodes_number)):
        j = 0
        #print(j)
        for j in range(0,nodes_number):
            if j>i:
                rand_edge(G=G,vi=i,vj=j,p=p)
                j+=1
        #print(i,j)
        i+=1
    return G


import networkx as nx
import numpy as np
import scipy as sp


def distribution_of_degree(G):   #
    d = nx.degree(G)
    print(d)
    d = dict(nx.degree(G))
    degree_list = np.array(d.values())
    Distribution = nx.degree_histogram(G)
    Distribution = np.array(Distribution)
    p_k = Distribution/len(G.nodes)
    #print(p_k)
    k = np.array(range(0,len(Distribution)))
    #print(k)
    return p_k,k

def NDNW_average_degree(G):
    number_of_edges = G.number_of_edges()
    number_of_nodes = G.number_of_nodes()
    average_degree = (2*number_of_edges)/number_of_nodes
    return average_degree
def DNW_average_degree(G):
    number_of_edges = G.number_of_edges()
    number_of_nodes = G.number_of_nodes()
    average_degree = (number_of_edges)/number_of_nodes
    return average_degree

def catagory_of_network(G):
    av = NDNW_average_degree(G)
    number_of_nodes = G.number_of_nodes()
    if av<1:
        print("该网络为亚临界状态网络")
    elif av==1:
        print("该网络为临界状态网络")
    elif av>1 and av<np.log(number_of_nodes):
        print("该网络为超临界状态网络")
    elif av>=np.log(number_of_nodes):
        print("该网络为连通状态网络")
    else:
        print("ERROR,PLEASE CHECK YOUR GRAPH!")

def NDNW_network_diameter(G):
    dmax = np.log(G.number_of_nodes())/np.log(NDNW_average_degree(G))
    return dmax

def DNW_network_diameter(G):
    dmax = np.log(G.number_of_nodes())/np.log(DNW_average_degree(G))
    return dmax

def natural_cutoff(G,func,kmin):
    number_of_nodes = G.number_of_nodes()
    result = sp.integrate.quad(func,kmin,np.pi)
    return result



import networkx as nx
import matplotlib.pyplot as plt

def draw_random_layout_networks(G,figsize1,figsize2,with_labels=False,font_size=1,node_size = 200,line_width=0.3,color="red"):
    pos = nx.random_layout(G)
    plt.figure(figsize=(figsize1,figsize2))
    options = {
        "with_labels": with_labels,
        "font_size": font_size,
        "font_weight": "bold",
        "font_color": "white",
        "node_size": node_size,
        "width": line_width,
        "node_color":color
    }
    nx.draw_networkx(G, pos, **options)
    ax = plt.gca()
    ax.margins(0.20)
    plt.axis("off")
    plt.show()

def draw_DD(k,p_k,bar_width=0.5,color="red",xlabel="$k$",ylabel="$p_k$",xlim1=0,xlim2=10):
    plt.bar(k, p_k, width=bar_width, color=color)
    plt.xlabel(xlabel)
    plt.ylabel(ylabel)
    plt.xlim([xlim1,xlim2])


import setuptools

requirements = ['numpy','matplotlib','networkx','tqdm','scipy']       # 自定义工具中需要的依赖包

setuptools.setup(
    name="HIT_network",       # 自定义工具包的名字
    version="0.0.3",             # 版本号
    author="Jinyan",           # 作者名字
    author_email="duanjinyan8866@outlook.com",  # 作者邮箱
    description="This is an integrated shortcut network related programming toolkit, the content is still in the development stage", # 自定义工具包的简介
    license='MIT-0',           # 许可协议
    url="https://github.com/656756130/Network_basementlearning",              # 项目开源地址
    packages=setuptools.find_packages(),  # 自动发现自定义工具包中的所有包和子包
    install_requires=requirements,  # 安装自定义工具包需要依赖的包
    python_requires='>=3.5'         # 自定义工具包对于python版本的要求
)